@@ -109,6 +109,8 @@ class FABRICSSHKeyTest(unittest.TestCase):
 
     def testValidRSA(self):
         rsak = FABRICSSHKey(RSA_PUB_3072)
+        rsak1 = FABRICSSHKey(RSA_PUB_3072)
+        self.assertTrue(rsak == rsak1)
         self.assertEqual(rsak.length, 3072)
         # compared to ssh-keygen -lf <file> -E md5
         self.assertEqual(rsak.get_fingerprint(), "MD5:14:68:04:d5:8a:f7:03:1b:a5:14:26:62:77:d8:15:4e")
@@ -125,6 +127,10 @@ class FABRICSSHKeyTest(unittest.TestCase):
 
     def testValidECDSA(self):
         ecdsak = FABRICSSHKey(ECDSA_PUB_256)
+        ecdsak1 = FABRICSSHKey(ECDSA_PUB_256)
+        ecdsak2 = FABRICSSHKey(ECDSA_PUB_384)
+        self.assertTrue(ecdsak == ecdsak1)
+        self.assertFalse(ecdsak == ecdsak2)
         self.assertEqual(ecdsak.length, 256)
         self.assertEqual(ecdsak.get_fingerprint(), "MD5:ed:6f:f4:0d:09:5b:80:d9:f4:16:ab:71:d1:b5:76:a3")
         self.assertEqual(ecdsak.get_fingerprint(kind='sha256'), "SHA256:YUoqrMjtU0kOtvvCe3jumvaf2wmEV+N8LjGT16fRu3I")
